#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : BertZoo.
# @File         : __init__.py
# @Time         : 2020/11/25 3:24 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


# from .SimBert import SimBert
